Index: pkg/http/lib/src/request.dart |
diff --git a/pkg/http/lib/src/request.dart b/pkg/http/lib/src/request.dart |
index 574070a3103e6338b722ec19975a12f77528383a..670bc4837228ec756b1caf6ae70ac963d80003b3 100644 |
--- a/pkg/http/lib/src/request.dart |
+++ b/pkg/http/lib/src/request.dart |
@@ -4,11 +4,13 @@ |
library request; |
+import 'dart:async'; |
import 'dart:io'; |
import 'dart:scalarlist'; |
import 'dart:uri'; |
import 'base_request.dart'; |
+import 'byte_stream.dart'; |
import 'utils.dart'; |
/// An HTTP request where the entire request body is known in advance. |
@@ -131,15 +133,11 @@ class Request extends BaseRequest { |
_defaultEncoding = Encoding.UTF_8, |
_bodyBytes = new Uint8List(0); |
- /// Freeze all mutable fields and return an [InputStream] containing the |
- /// request body. |
- InputStream finalize() { |
+ /// Freezes all mutable fields and returns a single-subscription [ByteStream] |
+ /// containing the request body. |
+ ByteStream finalize() { |
super.finalize(); |
- |
- var stream = new ListInputStream(); |
- stream.write(bodyBytes); |
- stream.markEndOfStream(); |
- return stream; |
+ return new ByteStream.fromBytes(bodyBytes); |
} |
/// The `Content-Type` header of the request (if it exists) as a |